/* Copyright (C) 1996 Bjoern Beutel. */

/* Description. =============================================================*/

/* Managing the display process from Malaga. */

/* Variables. ===============================================================*/

extern FILE *display_stream; /* Stream to send data to the display process. */

/* Functions. ===============================================================*/

extern void start_display_process( void );
/* Start the Malaga display process by executing DISPLAY_COMMAND_LINE
 * if it is not already running. */

extern void stop_display_process( void );
/* Stop the Malaga display process. */

/* Commands. ================================================================*/

extern command_t display_cmd_option;
/* Set the command line to start the display process. */

/* End of file. =============================================================*/
